@@ -183,12 +183,11 @@ class TestPO2TxtCommand(test_convert.TestConvertCommand, TestPO2Txt):
     convertmodule = po2txt
     defaultoptions = {"progress": "none"}
 
-    def test_help(self, capsys):
-        """tests getting help"""
-        options = super().test_help(capsys)
-        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
-        options = self.help_check(options, "--threshold=PERCENT")
-        options = self.help_check(options, "--fuzzy")
-        options = self.help_check(options, "--nofuzzy")
-        options = self.help_check(options, "--encoding")
-        options = self.help_check(options, "-w WRAP, --wrap=WRAP", last=True)
+    expected_options = [
+        "-t TEMPLATE, --template=TEMPLATE",
+        "--threshold=PERCENT",
+        "--fuzzy",
+        "--nofuzzy",
+        "--encoding",
+        "-w WRAP, --wrap=WRAP",
+    ]
