@@ -42,7 +42,7 @@ class AndroidResourceUnit(base.TranslationUnit):
     def createfromxmlElement(cls, element):
         term = None
         # Actually this class supports only plurals and string tags
-        if element.tag == "plurals" or element.tag == "string":
+        if element.tag in ("plurals", "string"):
             term = cls(None, xmlelement=element)
         return term
 
@@ -73,7 +73,8 @@ class AndroidResourceUnit(base.TranslationUnit):
     def getcontext(self):
         return self.xmlelement.get("name")
 
-    def unescape(self, text, strip=True):
+    @staticmethod
+    def unescape(text, strip=True):
         """
         Remove escaping from Android resource.
 
@@ -161,7 +162,7 @@ class AndroidResourceUnit(base.TranslationUnit):
                         # this first so we can use the ``in`` operator
                         # in the clauses below without issue.
                         pass
-                    elif c == "n" or c == "N":
+                    elif c in ("n", "N"):
                         # Remove whitespace just before newline. Most likely this is result of
                         # having real newline in the XML in front of \n.
                         if i >= 2 and text[i - 2] == " ":
@@ -170,7 +171,7 @@ class AndroidResourceUnit(base.TranslationUnit):
                             offset = 1
                         text[i - offset : i + 1] = "\n"  # an actual newline
                         i -= offset
-                    elif c == "t" or c == "T":
+                    elif c in ("t", "T"):
                         text[i - 1 : i + 1] = "\t"  # an actual tab
                         i -= 1
                     elif c == " ":
@@ -218,7 +219,8 @@ class AndroidResourceUnit(base.TranslationUnit):
         # Join the string together again, but w/o EOF marker
         return "".join(text[:-1])
 
-    def xml_escape_space(self, matchobj):
+    @staticmethod
+    def xml_escape_space(matchobj):
         return matchobj.group(0).replace("  ", r" \u0020")
 
     def escape(self, text, quote_wrapping_whitespaces=True):
@@ -291,10 +293,8 @@ class AndroidResourceUnit(base.TranslationUnit):
 
             # Include markup as well
             target += "".join(
-                [
-                    etree.tostring(child, encoding="unicode")
-                    for child in cloned_target.iterchildren()
-                ]
+                etree.tostring(child, encoding="unicode")
+                for child in cloned_target.iterchildren()
             )
             return target
 
@@ -351,16 +351,33 @@ class AndroidResourceUnit(base.TranslationUnit):
         else:
             self.set_xml_text_plain(target, xmltarget)
 
+    def gettargetlanguage(self):
+        if self._store is None:
+            return "en"
+        return super().gettargetlanguage()
+
+    def get_plural_tags(self):
+        locale = self.gettargetlanguage()
+        if not locale:
+            return data.plural_tags["en"]
+        # Handle b+ style language codes
+        if locale.startswith("b+"):
+            locale = locale[2:]
+        locale = locale.replace("_", "-").replace("+", "-").split("-")[0]
+        return data.plural_tags.get(locale, data.plural_tags["en"])
+
     @property
     def target(self):
         if self.xmlelement.tag != "plurals":
             return self.get_xml_text_value(self.xmlelement)
-        return multistring(
-            [
-                self.get_xml_text_value(entry)
-                for entry in self.xmlelement.iterchildren("item")
-            ]
-        )
+        plurals = {
+            entry.get("quantity"): self.get_xml_text_value(entry)
+            for entry in self.xmlelement.iterchildren("item")
+        }
+        plural_tags = self.get_plural_tags()
+        print(plurals, plural_tags)
+        print([plurals.get(tag, "") for tag in plural_tags])
+        return multistring([plurals.get(tag, "") for tag in plural_tags])
 
     @target.setter
     def target(self, target):
@@ -371,8 +388,7 @@ class AndroidResourceUnit(base.TranslationUnit):
                 self.xmlelement = etree.Element("plurals")
                 self.setid(old_id)
 
-            locale = self.gettargetlanguage().replace("_", "-").split("-")[0]
-            plural_tags = data.plural_tags.get(locale, data.plural_tags["en"])
+            plural_tags = self.get_plural_tags()
 
             # Get string list to handle, wrapping non multistring/list targets into a list.
             if isinstance(target, multistring):
@@ -455,7 +471,8 @@ class AndroidResourceUnit(base.TranslationUnit):
     def __eq__(self, other):
         return str(self) == str(other)
 
-    def hasplurals(self, thing):
+    @staticmethod
+    def hasplurals(thing):
         if isinstance(thing, multistring):
             return True
         elif isinstance(thing, list):
@@ -475,7 +492,7 @@ class AndroidResourceFile(lisa.LISAfile):
     XMLskeleton = """<?xml version="1.0" encoding="utf-8"?>
 <resources></resources>"""
     XMLindent = {"indent": "    ", "leaves": {"string", "item"}}
-    XMLdoublequotes = True
+    XMLuppercaseEncoding = False
 
     def initbody(self):
         """Initialises self.body so it never needs to be retrieved from the XML
