@@ -205,12 +205,11 @@ class JsonFile(base.DictStore):
                     item, stop, prev + [("index", i)], i, name_node, data
                 )
         # apply filter
-        elif (
+        elif prev.parts and (
             stop is None
             or (isinstance(last_node, dict) and name_node in stop)
             or (isinstance(last_node, list) and name_last_node in stop)
         ):
-
             unit = self.UnitClass(data, name_node)
             unit.set_unitid(prev)
             yield unit
@@ -230,6 +229,8 @@ class JsonFile(base.DictStore):
             # that parse JSON texts MAY ignore the presence of a byte order mark
             # rather than treating it as an error, see RFC7159
             input, self.encoding = self.detect_encoding(input)
+            if input is None:
+                raise base.ParseError(ValueError("Failed to decode JSON string."))
         try:
             self._file = json.loads(input, object_pairs_hook=OrderedDict)
         except ValueError as e:
@@ -520,7 +521,7 @@ class ARBJsonFile(JsonFile):
     See following URLs for doc:
 
     https://github.com/google/app-resource-bundle/wiki/ApplicationResourceBundleSpecification
-    https://flutter.dev/docs/development/accessibility-and-localization/internationalization#appendix-using-the-dart-intl-tools
+    https://docs.flutter.dev/development/accessibility-and-localization/internationalization#dart-tools
     """
 
     UnitClass = ARBJsonUnit
